pub struct LatestStatus {
pub height: Option<u64>,
pub block_hash: Option<Hash>,
pub valset_hash: Option<Hash>,
pub connected_nodes: Vec<PeerId>,
}Expand description
Contains the local status information, like the latest height, latest block and valset hashes, list of of connected full nodes (primary and witnesses).
Fields
height: Option<u64>The latest height we are trusting.
block_hash: Option<Hash>The latest block hash we are trusting.
valset_hash: Option<Hash>The latest validator set we are trusting. Note that this potentially did not yet sign a header yet.
connected_nodes: Vec<PeerId>The list of fullnodes we are connected to, primary and witnesses.
Implementations