LightBlock

Struct LightBlock 

pub struct LightBlock {
    pub signed_header: SignedHeader,
    pub validators: ValidatorSet,
    pub next_validators: ValidatorSet,
    pub provider: PeerId,
}
A light block is the core data structure used by the light client. It records everything the light client needs to know about a block.

Fields

signed_header: SignedHeader

Header and commit of this block

validators: ValidatorSet

Validator set at the block height

next_validators: ValidatorSet

Validator set at the next block height

provider: PeerId

The peer ID of the node that provided this block

Implementations

Source

impl LightBlock

pub fn new( signed_header: SignedHeader, validators: ValidatorSet, next_validators: ValidatorSet, provider: PeerId, ) -> LightBlock

Constructs a new light block

pub fn height(&self) -> Height

Returns the height of this block.

Note

This is a shorthand for block.signed_header.header.height.

pub fn time(&self) -> Time

Returns the time at which this block was created.

Note

This is a shorthand for block.signed_header.header.time.

pub fn as_trusted_state(&self) -> TrustedBlockState<'_>

Obtain the verification parameters for the light block when using it as trusted state.

pub fn as_untrusted_state(&self) -> UntrustedBlockState<'_>

Obtain the verification parameters for the light block when using it as untrusted state.